@@ -2,8 +2,9 @@ import sys
 
 import click
 
-from .config import get_config_dict, get_used_settings_message, parse_config_dict
-from .generators.package import PackageGenerator
+from .client_generators.package import PackageGenerator
+from .config import get_client_settings, get_config_dict, get_graphql_schema_settings
+from .graphql_schema_generators.schema import generate_graphql_schema_file
 from .plugins.explorer import get_plugins_types
 from .plugins.manager import PluginManager
 from .schema import (
@@ -13,20 +14,37 @@ from .schema import (
     get_graphql_schema_from_path,
     get_graphql_schema_from_url,
 )
+from .settings import Strategy
 
 
 @click.command()
 @click.version_option()
 @click.option("--config", default=None, help="Path to custom configuration file.")
-def main(config=None):
+@click.argument(
+    "strategy",
+    default=Strategy.CLIENT,
+    type=click.Choice([e.value for e in Strategy]),
+    required=False,
+)
+def main(strategy=Strategy.CLIENT, config=None):
     config_dict = get_config_dict(config)
-    settings = parse_config_dict(config_dict)
+    if strategy == Strategy.CLIENT:
+        client(config_dict)
+
+    if strategy == Strategy.GRAPHQL_SCHEMA:
+        graphql_schema(config_dict)
+
+
+def client(config_dict):
+    settings = get_client_settings(config_dict)
     if settings.schema_path:
         schema = get_graphql_schema_from_path(settings.schema_path)
         schema_source = settings.schema_path
     else:
         schema = get_graphql_schema_from_url(
-            url=settings.remote_schema_url, headers=settings.remote_schema_headers
+            url=settings.remote_schema_url,
+            headers=settings.remote_schema_headers,
+            verify_ssl=settings.remote_schema_verify_ssl,
         )
         schema_source = settings.remote_schema_url
 
@@ -34,7 +52,7 @@ def main(config=None):
     queries = filter_operations_definitions(definitions)
     fragments = filter_fragments_definitions(definitions)
 
-    sys.stdout.write(get_used_settings_message(settings))
+    sys.stdout.write(settings.used_settings_message)
 
     package_generator = PackageGenerator(
         package_name=settings.target_package_name,
@@ -66,5 +84,27 @@ def main(config=None):
     sys.stdout.write("\nGenerated files:\n  " + "\n  ".join(generated_files) + "\n")
 
 
+def graphql_schema(config_dict):
+    settings = get_graphql_schema_settings(config_dict)
+    sys.stdout.write(settings.used_settings_message)
+
+    schema = (
+        get_graphql_schema_from_path(settings.schema_path)
+        if settings.schema_path
+        else get_graphql_schema_from_url(
+            url=settings.remote_schema_url,
+            headers=settings.remote_schema_headers,
+            verify_ssl=settings.remote_schema_verify_ssl,
+        )
+    )
+
+    generate_graphql_schema_file(
+        schema=schema,
+        target_file_path=settings.target_file_path,
+        type_map_name=settings.type_map_variable_name,
+        schema_variable_name=settings.schema_variable_name,
+    )
+
+
 if __name__ == "__main__":
     main()
